@@ -14,4 +14,4 @@
 # limitations under the Licence, but note it is strictly for non-commercial use.
 """Module for conversion between IBM Qiskit and :math:`\\mathrm{t|ket}\\rangle` primitives."""
 from .qiskit_convert import qiskit_to_tk, tk_to_qiskit
-from .tket_pass import TketPass
\ No newline at end of file
+# from .tket_pass import TketPass
\ No newline at end of file
